@@ -1,10 +1,14 @@
 package Acme::CPANModules::FooThis;
 
-our $DATE = '2021-05-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+use strict;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-10-29'; # DATE
+our $DIST = 'Acme-CPANModules-FooThis'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 our $LIST = {
-    summary => "Export your directory over various channels",
+    summary => "List of modules/tools to export your directory over various channels",
     entries => [
         {
             module => 'App::HTTPThis',
@@ -30,7 +34,7 @@ our $LIST = {
 };
 
 1;
-# ABSTRACT: Export your directory over various channels
+# ABSTRACT: List of modules/tools to export your directory over various channels
 
 __END__
 
@@ -40,11 +44,11 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModules::FooThis - Export your directory over various channels
+Acme::CPANModules::FooThis - List of modules/tools to export your directory over various channels
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::FooThis (from Perl distribution Acme-CPANModules-FooThis), released on 2021-05-22.
+This document describes version 0.003 of Acme::CPANModules::FooThis (from Perl distribution Acme-CPANModules-FooThis), released on 2023-10-29.
 
 =head1 DESCRIPTION
 
@@ -52,15 +56,35 @@ This document describes version 0.002 of Acme::CPANModules::FooThis (from Perl d
 
 =over
 
-=item * L<App::HTTPThis>
+=item L<App::HTTPThis>
 
-=item * L<App::HTTPSThis>
+Author: L<DAVECROSS|https://metacpan.org/author/DAVECROSS>
 
-=item * L<App::DAVThis>
+Script: L<http_this>
 
-=item * L<App::FTPThis>
+=item L<App::HTTPSThis>
 
-=item * L<App::CGIThis>
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+Script: L<https_this>
+
+=item L<App::DAVThis>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+Script: L<dav_this>
+
+=item L<App::FTPThis>
+
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+Script: L<ftp_this>
+
+=item L<App::CGIThis>
+
+Author: L<SIMBABQUE|https://metacpan.org/author/SIMBABQUE>
+
+Script: L<cgi_this>
 
 =back
 
@@ -96,6 +120,8 @@ or directly:
 This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
 result for C<lcpan related-mods> command when it comes to finding related
 modules for the modules listed in this Acme::CPANModules module.
+See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
+are found.
 
 =head1 HOMEPAGE
 
@@ -105,14 +131,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANM
 
 Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-FooThis>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-CPANModules-FooThis/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Acme::CPANModules> - about the Acme::CPANModules namespace
@@ -123,11 +141,37 @@ L<cpanmodules> - CLI tool to let you browse/view the lists
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2021, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModules-FooThis>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
